==> form_validator-1.0.3.tar.gz: CHANGELOG.md <==
## [1.0.3] - 10/7/2022

- Added Russian language support - [#36](https://github.com/themisir/form-validator/pull/36)
- Added Thai language support - [#39](https://github.com/themisir/form-validator/pull/39), [#40](https://github.com/themisir/form-validator/pull/40)
- Added Romanian language support - [#42](https://github.com/themisir/form-validator/pull/42)
- Improved Japanese messages - [#35](https://github.com/themisir/form-validator/pull/35), [#44](https://github.com/themisir/form-validator/pull/44)

## [1.0.2] - 2/10/2022

- Added Herbew language support - [#32](https://github.com/themisir/form-validator/pull/32)
- Added Japaniese language support - [#33](https://github.com/themisir/form-validator/pull/33)
- Minor internal refactoring

## [1.0.1] - 11/17/2021

- Added Espanol language support - [#28](https://github.com/themisir/form-validator/pull/28)

## [1.0.0-nullsafety.1] - 4/10/2021

- Fixed `.required()` not working - [#17](https://github.com/TheMisir/form-validator/issues/17)

## [1.0.0-nullsafety.0] - 4/10/2021

- Null safety support for Dart 2.12

## [0.1.7] - 12/26/2020

- Added Indonesian language
- Added Brazilian Portuguese language

## [0.1.5] - 8/21/2020

- Added German language

## [0.1.4+1] - 8/11/2020

- Fixed analysis warnings

## [0.1.4] - 8/11/2020

- Added French language

## [0.1.3] - 6/13/2020

- Added Turkish language

## [0.1.2] - 6/12/2020

- Added messages for english

## [0.1.1+2] - 6/7/2020

- Added documentation

## [0.1.1] - 6/7/2020

- Added example

## [0.1.0] - 6/7/2020

- Initial release


_Timestamps are in MM/DD/YYYY format_

==> form_validator-1.0.4.tar.gz: CHANGELOG.md <==
## [1.0.4] - 27.11.2022

- Added Vietnamese language support - [#48](https://github.com/themisir/form-validator/pull/48)

## [1.0.3] - 07.10.2022

- Added Russian language support - [#36](https://github.com/themisir/form-validator/pull/36)
- Added Thai language support - [#39](https://github.com/themisir/form-validator/pull/39), [#40](https://github.com/themisir/form-validator/pull/40)
- Added Romanian language support - [#42](https://github.com/themisir/form-validator/pull/42)
- Improved Japanese messages - [#35](https://github.com/themisir/form-validator/pull/35), [#44](https://github.com/themisir/form-validator/pull/44)

## [1.0.2] - 10.02.2022

- Added Herbew language support - [#32](https://github.com/themisir/form-validator/pull/32)
- Added Japaniese language support - [#33](https://github.com/themisir/form-validator/pull/33)
- Minor internal refactoring

## [1.0.1] - 17.11.2021

- Added Espanol language support - [#28](https://github.com/themisir/form-validator/pull/28)

## [1.0.0-nullsafety.1] - 10.04.2021

- Fixed `.required()` not working - [#17](https://github.com/TheMisir/form-validator/issues/17)

## [1.0.0-nullsafety.0] - 10.04.2021

- Null safety support for Dart 2.12

## [0.1.7] - 26.12.2020

- Added Indonesian language
- Added Brazilian Portuguese language

## [0.1.5] - 21.08.2020

- Added German language

## [0.1.4+1] - 11.08.2020

- Fixed analysis warnings

## [0.1.4] - 11.08.2020

- Added French language

## [0.1.3] - 13.06.2020

- Added Turkish language

## [0.1.2] - 12.06.2020

- Added messages for english

## [0.1.1+2] - 07.06.2020

- Added documentation

## [0.1.1] - 07.06.2020

- Added example

## [0.1.0] - 07.06.2020

- Initial release
